@@ -20,21 +20,31 @@
 #define FORCE_GENERATE_OPTION               9
 #define MOUSE_LIST_OPTION                   10
 #define MODE_OPTION                         11
-#define REMOVE_MODE_OPTION                  12
-#define NVIDIA_CFG_PATH_OPTION              13
-#define NVAGP_OPTION                        14
-#define SLI_OPTION                          15
-#define DISABLE_SCF_OPTION                  16
-#define TRANSPARENT_INDEX_OPTION            17
-#define STEREO_OPTION                       18
-#define ROTATE_OPTION                       19
-#define QUERY_GPU_INFO_OPTION               20
-#define EXTRACT_EDIDS_OUTPUT_FILE_OPTION    21
-#define MULTI_GPU_OPTION                    22
-#define TWINVIEW_XINERAMA_INFO_ORDER_OPTION 23
-#define LOGO_PATH_OPTION                    24
-#define TWINVIEW_ORIENTATION_OPTION         25
-#define VIRTUAL_OPTION                      26
+#define MODE_LIST_OPTION                    12
+#define REMOVE_MODE_OPTION                  13
+#define NVIDIA_CFG_PATH_OPTION              14
+#define NVAGP_OPTION                        15
+#define SLI_OPTION                          16
+#define DISABLE_SCF_OPTION                  17
+#define TRANSPARENT_INDEX_OPTION            18
+#define STEREO_OPTION                       19
+#define ROTATE_OPTION                       20
+#define QUERY_GPU_INFO_OPTION               21
+#define EXTRACT_EDIDS_OUTPUT_FILE_OPTION    22
+#define MULTI_GPU_OPTION                    23
+#define TWINVIEW_XINERAMA_INFO_ORDER_OPTION 24
+#define LOGO_PATH_OPTION                    25
+#define TWINVIEW_ORIENTATION_OPTION         26
+#define VIRTUAL_OPTION                      27
+#define USE_DISPLAY_DEVICE_OPTION           28
+#define CUSTOM_EDID_OPTION                  29
+#define TV_STANDARD_OPTION                  30
+#define TV_OUT_FORMAT_OPTION                31
+#define TV_OVER_SCAN_OPTION                 32
+#define COOL_BITS_OPTION                    33
+#define ACPID_SOCKET_PATH_OPTION            34
+#define HANDLE_SPECIAL_KEYS_OPTION          35
+#define PRESERVE_DRIVER_NAME_OPTION         36
 
 /*
  * To add a boolean option to nvidia-xconfig:
@@ -112,16 +122,19 @@ static const NVGetoptOption __options[] = {
 
     /* These options are only printed by "nvidia-xconfig --advanced-help" */
 
+    { "acpid-socket-path", 
+      ACPID_SOCKET_PATH_OPTION, 
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
+      "Set this option to specify an alternate path to the Linux ACPI daemon "
+      "(acpid)'s socket, which the NVIDIA X driver will use to connect to "
+      "acpid." },
+
     { "add-argb-glx-visuals",
       XCONFIG_BOOL_VAL(ADD_ARGB_GLX_VISUALS_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN,  NULL,
       "Enables or disables support for OpenGL rendering into 32-bit ARGB "
       "windows and pixmaps." },
 
-    { "allow-ddcci", XCONFIG_BOOL_VAL(ALLOW_DDCCI_BOOL_OPTION),
-      NVGETOPT_IS_BOOLEAN,  NULL, "Enables or disables DDC/CI support in the "
-      "NV-CONTROL X extension." },
-
     { "allow-dfp-stereo", XCONFIG_BOOL_VAL(ALLOW_DFP_STEREO_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN, NULL,
       "Enable or disable the \"AllowDFPStereo\" X configuration option." },
@@ -136,10 +149,24 @@ static const NVGetoptOption __options[] = {
       NVGETOPT_IS_BOOLEAN, NULL,
       "Disable or enable the \"NoBandWidthTest\" X configuration option." },
 
+    { "cool-bits", COOL_BITS_OPTION,
+      NVGETOPT_INTEGER_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
+      "Enable or disable the \"Coolbits\" X configuration option. Setting this "
+      "option will enable support in the NV-CONTROL X extension for manipulating "
+      "GPU clock settings. Default value is 0.\n"
+      "WARNING: this may cause system damage and void warranties." },
+
     { "composite",
       XCONFIG_BOOL_VAL(COMPOSITE_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
       "Enable or disable the \"Composite\" X extension." },
 
+    { "connect-to-acpid",
+      XCONFIG_BOOL_VAL(CONNECT_TO_ACPID_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
+      "Enable or disable the \"ConnectToAcpid\" X configuration option.  "
+      "If this option is set, the NVIDIA X driver will attempt to connect "
+      "to the Linux ACPI daemon (acpid).  Set this option to off to prevent "
+      "the X driver from attempting to connect to acpid." },
+
     { "constant-dpi",
       XCONFIG_BOOL_VAL(CONSTANT_DPI_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
       "Enable or disable the \"ConstantDPI\" X configuration option, "
@@ -148,15 +175,24 @@ static const NVGetoptOption __options[] = {
       "millimeters of the X screen when XRandR changes the size in pixels "
       "of the X screen." },
 
+    { "custom-edid", CUSTOM_EDID_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "CUSTOM-EDID",
+      "Enable or disable the  \"CustomEDID\" X configuration option; "
+      "setting this option forces the X driver to use the EDID specified."
+      "This option is a semicolon-separated list of pairs of display device names "
+      "and filename pairs; e.g \"CRT-0:\\tmp\\edid.bin\". Note that a display "
+      "device name must always be specified even if only one EDID is"
+      " specified. " },
+
     { "dac-8bit", XCONFIG_BOOL_VAL(DAC_8BIT_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN, NULL,
       "Most Quadro parts by default use a 10 bit color look up table (LUT) "
       "by default; setting this option to TRUE forces these graphics chips "
       "to use an 8 bit (LUT)." },
-    
+
     { "depth", 'd', NVGETOPT_INTEGER_ARGUMENT, NULL,
       "Set the default depth to [DEPTH]; valid values for [DEPTH] are "
-      "8, 15, 16 and 24." },
+      "8, 15, 16, 24, and 30." },
 
     { "disable-glx-root-clipping",
       XCONFIG_BOOL_VAL(DISABLE_GLX_ROOT_CLIPPING_BOOL_OPTION),
@@ -170,7 +206,7 @@ static const NVGetoptOption __options[] = {
       "when a direct-rendering client has performed rendering that needs to be "
       "composited to the screen.  Improves performance when using GLX with the "
       "composite extension." },
-    
+
 #if defined(NV_SUNOS)
     { "disable-scf", DISABLE_SCF_OPTION, 0, NULL,
       "On Solaris, nvidia-xconfig updates the service configuration "
@@ -185,16 +221,28 @@ static const NVGetoptOption __options[] = {
       NVGETOPT_IS_BOOLEAN, NULL,
       "Enable or disable support for dynamically configuring TwinView." },
     
+    { "preserve-driver-name", PRESERVE_DRIVER_NAME_OPTION, 0, NULL,
+      "By default nvidia-xconfig changes the  display  driver  to \"nvidia\" "
+      "for all configured X screens; this option preserves the existing driver "
+      "name of each X screen." },
+    
+    { "enable-acpi-hotkeys",
+      XCONFIG_BOOL_VAL(ENABLE_ACPI_HOTKEYS_BOOL_OPTION), 
+      NVGETOPT_IS_BOOLEAN, NULL,
+      "The \"EnableACPIHotkeys\" option can be specified to override the "
+      "NVIDIA X driver's default decision to enable or disable ACPI "
+      "display change hotkey events." },
+
     { "enable-all-gpus", 'a', 0, NULL,
       "Configure an X screen on every GPU in the system." },
-    
+
     { "exact-mode-timings-dvi",
       XCONFIG_BOOL_VAL(EXACT_MODE_TIMINGS_DVI_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN, NULL,
       "Forces the initialization of the X server with "
       "the exact timings specified in the ModeLine." },
 
-    { "extract-edids-from-log", 'E', NVGETOPT_STRING_ARGUMENT, "LOG",
+    { "extract-edids-from-file", 'E', NVGETOPT_STRING_ARGUMENT, "FILE",
       "Extract any raw EDID byte blocks contained in the specified X "
       "log file [LOG]; raw EDID bytes are printed by the NVIDIA X driver to "
       "the X log as hexidecimal when verbose logging is enabled with the "
@@ -202,8 +250,8 @@ static const NVGetoptOption __options[] = {
       "are then written as binary data to individual files.  These files "
       "can later be used by the NVIDIA X driver through the \"CustomEDID\" "
       "X configuration option." },
-    
-    { "extract-edids-output-file", 
+
+    { "extract-edids-output-file",
       EXTRACT_EDIDS_OUTPUT_FILE_OPTION, NVGETOPT_STRING_ARGUMENT, "FILENAME",
       "When the '--extract-edids-from-log' option is used, nvidia-xconfig "
       "writes any extracted EDID to a file, typically \"edid.bin\" in the "
@@ -230,6 +278,13 @@ static const NVGetoptOption __options[] = {
       "visible. This option forces stereo flipping even when no stereo "
       "drawables are visible." },
 
+    { "handle-special-keys", HANDLE_SPECIAL_KEYS_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "WHEN",
+      "Specify when the X server should use the builtin keyboard handler to "
+      "process special key combinations (such as Ctrl+Alt+Backspace); see "
+      "the X configuration man page for details.  The value of [WHEN] can be "
+      "'Always', 'Never', or 'WhenNeeded'." },
+
     { "include-implicit-metamodes",
       XCONFIG_BOOL_VAL(INCLUDE_IMPLICIT_METAMODES_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN, NULL,
@@ -268,7 +323,7 @@ static const NVGetoptOption __options[] = {
       NVGETOPT_IS_BOOLEAN, NULL,
       "Allow or disallow NVIDIA Linux X driver module to load the NVIDIA "
       "Linux kernel module automatically."},
-    
+
     { "logo",
       XCONFIG_BOOL_VAL(NOLOGO_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
       "Disable or enable the \"NoLogo\" X configuration option." },
@@ -282,6 +337,16 @@ static const NVGetoptOption __options[] = {
       MODE_OPTION, NVGETOPT_IS_BOOLEAN | NVGETOPT_STRING_ARGUMENT, NULL,
       "Add the specified mode to the mode list." },
 
+    { "mode-debug", XCONFIG_BOOL_VAL(MODE_DEBUG_BOOL_OPTION),
+      NVGETOPT_IS_BOOLEAN, NULL,
+      "Enable or disable the \"ModeDebug\" X configuration option; when "
+      "enabled, this option causes the X driver to print verbose details "
+      "about mode validation to the X log file." },
+
+    { "mode-list", MODE_LIST_OPTION, NVGETOPT_STRING_ARGUMENT, "MODELIST",
+      "Remove all existing modes from the X configuration's modelist and "
+      "add the one(s) specified in the [MODELIST] string." },
+
     { "remove-mode", REMOVE_MODE_OPTION, NVGETOPT_STRING_ARGUMENT, "MODE",
       "Remove the specified mode from the mode list." },
 
@@ -298,7 +363,7 @@ static const NVGetoptOption __options[] = {
 
     { "multigpu", MULTI_GPU_OPTION,
       NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
-      "Enable or disable MultiGPU.  Valid values for [MULTIGPU] are 'Off', "
+      "Enable or disable MultiGPU.  Valid values for [MULTIGPU] are 'Off', 'On',"
       " 'Auto', 'AFR', 'SFR', 'AA'." },
 
     { "multisample-compatibility",
@@ -361,11 +426,10 @@ static const NVGetoptOption __options[] = {
     { "probe-all-gpus", XCONFIG_BOOL_VAL(PROBE_ALL_GPUS_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN, NULL,
       "Disable or enable the \"ProbeAllGpus\" X configuration option." },
-      
-      
+
     { "query-gpu-info", QUERY_GPU_INFO_OPTION, 0, NULL,
       "Print information about all recognized NVIDIA GPUs in the system." },
-    
+
     { "randr-rotation",
       XCONFIG_BOOL_VAL(RANDR_ROTATION_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
       "Enable or disable the \"RandRRotation\" X configuration option." },
@@ -407,7 +471,7 @@ static const NVGetoptOption __options[] = {
 
     { "sli", SLI_OPTION,
       NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
-      "Enable or disable SLI.  Valid values for [SLI] are 'Off', 'Auto', "
+      "Enable or disable SLI.  Valid values for [SLI] are 'Off', 'On', 'Auto', "
       "'AFR', 'SFR', 'AA', 'AFRofAA'." },
 
     { "stereo", STEREO_OPTION,
@@ -417,6 +481,24 @@ static const NVGetoptOption __options[] = {
       "clone mode stereo), 5 (SeeReal digital flat panel), 6 (Sharp3D "
       "digital flat panel)." },
 
+    { "tv-standard", TV_STANDARD_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "TV-STANDARD",
+      "Enable or disable the \"TVStandard\" X configuration option. Valid "
+      "values for \"TVStandard\" are: \"PAL-B\", \"PAL-D\", \"PAL-G\", "
+      "\"PAL-H\", \"PAL-I\", \"PAL-K1\", \"PAL-M\", \"PAL-N\", \"PAL-NC\", "
+      "\"NTSC-J\", \"NTSC-M\", \"HD480i\", \"HD480p\", \"HD720p\", "
+      "\"HD1080i\", \"HD1080p\", \"HD576i\", \"HD576p\"." },
+
+    { "tv-out-format", TV_OUT_FORMAT_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "TV-OUT-FORMAT",
+      "Enable or disable the \"TVOutFormat\" X configuration option. Valid "
+      "values for \"TVOutFormat\" are: \"SVIDEO\" and \"COMPOSITE\"." },
+
+    { "tv-over-scan", TV_OVER_SCAN_OPTION,
+      NVGETOPT_DOUBLE_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
+      "Enable or disable the \"TVOverScan\" X configuration option. Valid "
+      "values are decimal values in the range 1.0 and 0.0." },
+
     { "twinview", XCONFIG_BOOL_VAL(TWINVIEW_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN, NULL, "Enable or disable TwinView." },
 
@@ -425,7 +507,7 @@ static const NVGetoptOption __options[] = {
       "Specify the TwinViewOrientation.  Valid values for [ORIENTATION] are: "
       "\"RightOf\" (the default), \"LeftOf\", \"Above\", \"Below\", or "
       "\"Clone\"." },
-    
+
     { "twinview-xinerama-info",
       XCONFIG_BOOL_VAL(NO_TWINVIEW_XINERAMA_INFO_BOOL_OPTION),
       NVGETOPT_IS_BOOLEAN, NULL,
@@ -460,7 +542,7 @@ static const NVGetoptOption __options[] = {
       "device's EDID, if any, to compute the DPI (Dots Per Inch) of the X "
       "screen.  This option defaults to TRUE (the NVIDIA X driver uses the "
       "EDID's physical size, when available, to compute the DPI)." },
-      
+
     { "use-edid-freqs",
       XCONFIG_BOOL_VAL(USE_EDID_FREQS_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
       "Enable or disable use of the HorizSync and VertRefresh "
@@ -476,10 +558,22 @@ static const NVGetoptOption __options[] = {
       "Enable use of the X Int10 module to soft-boot all secondary cards, "
       "rather than POSTing the cards through the NVIDIA kernel module." },
 
+    { "use-display-device", USE_DISPLAY_DEVICE_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "DISPLAY-DEVICE",
+      "Force the X driver to use the display device specified." },
+
+    { "use-events",
+      XCONFIG_BOOL_VAL(USE_EVENTS_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
+      "Enable or disable \"UseEvents\" X configuration option. Setting this "
+      "option will enable the X driver to use the system events in some cases "
+      "when it is waiting for the hardware. With this option X driver sets an "
+      "event handler and waits for the hardware through the poll() system "
+      "call. This option defaults to FALSE." },
+
     { "virtual", VIRTUAL_OPTION,
       NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "WIDTHxHEIGHT",
       "Specify the virtual screen resolution." },
-      
+
     { "x-prefix", X_PREFIX_OPTION, NVGETOPT_STRING_ARGUMENT, NULL,
       "The X installation prefix; the default is /usr/X11R6/.  Only "
       "under rare circumstances should this option be needed." },
@@ -492,6 +586,6 @@ static const NVGetoptOption __options[] = {
       NVGETOPT_IS_BOOLEAN, NULL,
       "Forces XvMC to use the 3D engine for XvMCPutSurface requests rather "
       "than the video overlay." },
-      
+
     { NULL, 0, 0, NULL, NULL },
 };
